#
# This code has been auto-generated by the MDE Workbench
# Version: 2.2.0.
#
# File: constants.py
# Date: 2021-05-13 10:59
# Time: 10:59
#


# Absolute tolerance for radiation calculations
ABS_TOL_RAD = 0.0000000001

# Flame shape adjusted if grounded for jet fires
ADJUST_GROUND_FLAME = 1

# DNV recommended atmospheric expansion method from orifice to final state
ATM_EXP_METHOD = 4

# Atmospheric molecular weight (kg/kmol)
ATM_MOLWT = 28.9505

# Atmospheric pressure (bar)
ATM_PRESSURE = 101325.0

# Along wind diffusion method for non instantaneous dispersion
AWD_FLAG = 3

# Calculate surface emissive power for fireballs
CALC_METHOD_SEP_FIREBALLS = -1

# Calculate surface emissive power for jet fires
CALC_METHOD_SEP_JET_FIRES = 0

# Critical separation ratio for concentration grids
CRIT_SEP_RATIO = 0.2

# Critical Webber number used in the droplet size calculations
CRIT_WEBER = 12.5

# Modified CCPS droplet method
DROPLET_METHOD = 6

# Explosion located at the cloud front (LFL fraction)
EXPL_LOCATION = 0

# Roberts/TNO hybrid fireball model
FIREBALL_MODEL = 0

# Use mass between LFL and UFL for flammable mass estimation in explosion calculations
FLAMM_MASS_CALC_METHOD = 2

# Kinetic energy fraction of discharge expansion energy
FRACTION_TOTAL_TO_KINETIC = 0.04

# Standard method for jet fire horizontal options
HORIZONTAL_OPTION = 0

# New standard method for modelling of instantaneous expansion
INEX_FLAG = 2

# Jet fire averaging time (s)
JET_FIRE_AVR_TIME = 20.0

# Recommended jet fire correlation
JET_FIRE_CORRELATION = 0

# Jet fire maximum exposure duration (s)
JET_FIRE_EXP_DUR = 20.0

# LFL fraction to finish
LFL_FRACTION = 0.5

# Mass modification factor used in calculating the mass of material involved in the fireball
MASS_MOD_FACTOR = 3.0

# Maximum integration step for dispersion calculations (s)
MAX_DISP_STEP_SIZE = 300.0

# Upper limit of the droplet diameter (m)
MAX_DROP_DIAMETER = 0.01

# Maximum number of flame coordinates for jet fires
MAX_NUMBER_FLAME_COORDINATES = 10

# Maximum release duration (s)
MAX_RELEASE_DURATION = 3600.0

# Maximum surface emissive power for fireballs (W/m2)
MAX_SEP_FIREBALL = 400000.0

# Maximum surface emissive power for a jet fire (W/m2)
MAX_SEP_JET_FIRE = 350000.0

# Maximum surface emissive power for pool fires (W/m2)
MAX_SEP_POOL_FIRE = 350000.0

# Maximum number of time steps for time varying releases
MAX_TIMESTEPS = 900

# Maximum release velocity (m/s)
MAX_VELOCITY = 100000000.0

# Fixed velocity capping method
MAX_VELOCITY_FLAG = 0

# Maximum number of components.
MAXIMUM_COMPONENT_COUNT = 20

# Maximum number of leak diameters for scenario generation
MAXIMUM_LEAK_DIAMETERS_COUNT = 5

# Maximum temperature allowed for dispersion calculations (K)
MAXIMUM_TEMPERATURE_LIMIT = 900.0

# Maximum number of weathers.
MAXIMUM_WEATHER_COUNT = 10

# Explosion efficiency for unconfined multi-energy explosions (%)
ME_EXPL_EFFICIENCY_UNCONFINED = 100.0

# Explosion efficiency for uniform confined multi-energy explosions (%)
ME_EXPL_EFFICIENCY_UNIFORM_CONFINED = 12.5

# Cut-off droplet diameter below which droplets are no longer modelled (m)
MIN_DROP_DIAMETER = 0.00000001

# Minimum explosive mass (kg)
MIN_EXPL_MASS = 0.0

# Minimum temperature allowed for dispersion calculations (K)
MINIMUM_TEMPERATURE_LIMIT = 11.0

# Number of time steps for continuous clouds used in explosion calculations
N_VTIMES_CONT = 5

# Maximum number of time steps for explosion calculations
N_VTIMES_MAX = 100

# Number of time steps for time-varying clouds used in explosion calculations
N_VTIMES_TV = 15

# Number of fixed size output steps for dispersion calculations
NUM_FIXED_STEPS = 20

# Number of steps in the downwind direction per explosion cloud view
NUM_X_VIEW = 21

# Planar observer type for radiation modelling
OBSERVER_TYPE = 1

# Core averaging time (s)
PASS_AV_TIME = 18.75

# Number of nodes on the pipe (start, end + intermediate)
PIPE_NODES_COUNT = 2

# Radiative fraction for general pool fires
RAD_FRAC_GENERAL = 0.4

# Probit value A for radiation
RAD_PROBIT_A = -36.38

# Probit value B for radiation
RAD_PROBIT_B = 2.56

# Probit value N for radiation
RAD_PROBIT_N = 1.33

# Reference height for wind speed
REF_HT_WIND_SPEED = 10.0

# Centreline height is used for explosion calculations
REPORTING_HEIGHT_FLAG = 1

# Flammable result grid step in x-direction (m)
RESULT_GRID_STEP = 10.0

# Cutoff for short duration effects. Only mass released until this time is used in the fireball calculation (s)
SHORT_DURATION_CUTOFF = 20.0

# Use old method (valid for paraffins only) for calculating the stoichiometric mass fraction
STOICH_MASS_FRAC_METHOD = 0

# Flame temperature for TNO fireball model (K)
TNO_FLAME_TEMP = 2000.0

# Toxics: minimum probability of death
TOXIC_MIN_LETHALITY = 0.001

# Product of each as the multi component toxic calculation method
TOXIC_MIX_CALC_METHOD = 3

# Prefer Probit as the toxic calculation method, i.e. if probit data is available that will be the preferred method to use
TOXIC_PROBIT_METHOD = 1

# Tail time for indoor toxic calculations (s)
TOXIC_TAIL_TIME = 1800.0

# Unconfined Multi-Energy explosion method
UNCONFINED_EXPLOSION_METHOD_OPTION = 1

# Unconfined explosion strength (Multi energy method)
UNCONFINED_EXPLOSION_STRENGTH = 2.0

# Uniform confined Multi Energy explosion method
UNIFORM_CONFINED_EXPLOSION_METHOD_OPTION = 3

# Use shape correlation for fireballs
USE_SHAPE_CORRELATION = -1

# Exclude solar radiation from radiation calculations
USE_SOLAR = 0

# Use volumes when specifying size of confined sources
USE_VOLUMES = 2

# Velocity for jet fire calculations must be user supplied
USER_INPUT_POST_EXPANSION_VELOCITY = 0

# Cut-off height for wind speed calculations 
WIND_CUTOFF_HEIGHT = 1.0

# Logarithmic wind profile
WIND_PROFILE_FLAG = 2

# Application constants.
PWS_CLIENT_ID = 'c02aee6b-4ab8-4fd8-9524-8bcd14617f1e'

# REST API URIs.
ANALYTICS_REST_API_URI = 'https://phastwebservices-preview.dnvgl.com/api/analytics/v1/'
