#!/usr/bin/python

"""
This module is callable via the command line
but importing it does nothing.
"""


def main():
    print('Welcome to Python Phast Web Services')


if __name__ == "__main__":
    main()
